/*
 boardCap.c
 ***********************************************************************
 This program captures a picture from our BoardFax by generating the
 poixel clock and sync pulse from the RaspberryPi while reading the 
 pixel data through another GPIO pin of the raspberryPi.

 pin0  output   pixel clock
 pin1  output   sync pulse (begin of the pixel line)
 pin2  input    pixel data


 CC BY-NC-SA 2014 c-hack.de
 2014-12-20 xsider	enhanced for nCLK and  RS pin 

 *********************************************************************** 
*/

#include <stdio.h>
#include <wiringPi.h>

#define PHI1   16  	/* Clock */
#define PHI2	1	/* Clock inverted */
#define	SH	15	/* Shift Gate */
#define RS	5	/* Reset Gate */
#define OS     	12	/* Signal Output, Pixel */
#define MOTOR1	6	/* Motorpulse1 */
#define MOTOR2	10	/* Motorpulse2 */
// Unbenutzt Eingang #4, digital 
// Unbenutzt Eingang #13, Komparator tut nicht
// Unbenutzt Eingang #14, Komparator
// Unbenutzt Eingang #11, Komparator

#define PIXEL_SIZE  2048
#define RAW_X 3000
#define RAW_Y 2500


char picture [RAW_X][RAW_Y];


int main(void)
{
  int i;

  printf("Raspberry Pi BoardFaxHack\n");
  printf("cc-by-sa-nc  2014   c-hack.de\n\n");
  printf("Capturing Data...\n");

  wiringPiSetup();
  for (i=0; i<16; i++) pinMode(i,INPUT);
  pinMode(PHI1, OUTPUT);
  pinMode(PHI2, OUTPUT);
  pinMode(SH, OUTPUT);
  pinMode(RS, OUTPUT);
  pinMode(OS, INPUT);
  
  /* ------ Initialize ------------------*/
  digitalWrite(PHI1, LOW);   // SYNC low
  digitalWrite(PHI2, LOW);    // Clock off
  
  /* ------------------------------------*/


  while (1) {
	  lineCapture(0);

	  for (i=0; i<RAW_Y; i++) 
//	i=1023;
	     if(picture[0][i] == 0) printf("."); else printf("#"); 
  }
  printf("Capture finished");
}


// Captures one line including overhead
void lineCapture(int x_index) {
   int i;
   int bit;

   digitalWrite(PHI1,HIGH);
   digitalWrite(PHI2,LOW);
   digitalWrite(SH,HIGH);   // One SYNC pulse
   delayMicroseconds(2);
   digitalWrite(SH,LOW);
   digitalWrite(PHI1,LOW);
   digitalWrite(PHI2,HIGH);
   delayMicroseconds(2);
   for (i=0; i<RAW_Y; i=i+2) {
      digitalWrite(PHI1, HIGH);
      digitalWrite(PHI2, LOW);
      delayMicroseconds(1);
      picture[x_index][i] = (char) digitalRead(OS);
      digitalWrite(RS,HIGH);
      digitalWrite(RS,LOW);
      digitalWrite(PHI1, LOW);
      digitalWrite(PHI2, HIGH);
      delayMicroseconds(1);
      picture[x_index][i+1] = (char) digitalRead(OS);
      digitalWrite(RS,HIGH);
      digitalWrite(RS,LOW);
   }
}
